@@ -152,6 +152,9 @@ class Repo(object):
             click.echo('%s is already installed' % package)
             return
 
+        if not os.path.exists(self.bin_dir):
+            os.mkdir(self.bin_dir)
+
         from subprocess import Popen
 
         def _cleanup():
@@ -167,17 +170,23 @@ class Repo(object):
             args.append('-p')
             args.append(python)
         args.append(venv_path)
-        if Popen(args).wait() != 0:
-            click.echo('Failed to create virtualenv.  Aborting.')
-            return _cleanup()
 
-        args = [os.path.join(venv_path, 'bin', 'pip'), 'install']
-        if editable:
-            args.append('--editable')
+        try:
+            if Popen(args).wait() != 0:
+                click.echo('Failed to create virtualenv.  Aborting.')
+                return _cleanup()
 
-        if Popen(args + install_args).wait() != 0:
-            click.echo('Failed to pip install.  Aborting.')
-            return _cleanup()
+            args = [os.path.join(venv_path, 'bin', 'pip'), 'install']
+            if editable:
+                args.append('--editable')
+
+            if Popen(args + install_args).wait() != 0:
+                click.echo('Failed to pip install.  Aborting.')
+                return _cleanup()
+        except Exception:
+            exc_type, exc_value, tb = sys.exc_info()
+            _cleanup()
+            raise exc_type, exc_value, tb
 
         # Find all the scripts
         scripts = self.find_scripts(venv_path, package)
